@@ -6,7 +6,7 @@ import sys
 from textwrap import indent
 from ..__version__ import __version__
 from .. import __package__ as __top_package__
-from ..runner import all_runners
+from ..runner import all_runners, default_runner
 from ..util import runner_name
 
 def register_parser(subparser):
@@ -14,7 +14,7 @@ def register_parser(subparser):
 
     parser.add_argument(
         "--verbose",
-        help   = "Show versions of individual Nextstrain components in the image",
+        help   = "Show versions of individual Nextstrain components in each runtime",
         action = "store_true")
 
     return parser
@@ -32,7 +32,7 @@ def run(opts):
 
         print("Runners")
         for runner in all_runners:
-            print("  " + runner_name(runner))
+            print("  " + runner_name(runner), "(default)" if runner is default_runner else "")
             versions = list(runner.versions())
             if versions:
                 for version in versions:
